# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github_com/TheThingsNetwork/api/networkserver/networkserver.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ttn.github_com.gogo.protobuf.gogoproto import gogo_pb2 as github__com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2
from ttn.github_com.TheThingsNetwork.api import api_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_api__pb2
from ttn.github_com.TheThingsNetwork.api.protocol.lorawan import device_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2
from ttn.github_com.TheThingsNetwork.api.broker import broker_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2
from ttn.github_com.TheThingsNetwork.api.handler import handler_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github_com/TheThingsNetwork/api/networkserver/networkserver.proto',
  package='networkserver',
  syntax='proto3',
  serialized_pb=_b('\nAgithub_com/TheThingsNetwork/api/networkserver/networkserver.proto\x12\rnetworkserver\x1a-github_com/gogo/protobuf/gogoproto/gogo.proto\x1a)github_com/TheThingsNetwork/api/api.proto\x1a=github_com/TheThingsNetwork/api/protocol/lorawan/device.proto\x1a\x33github_com/TheThingsNetwork/api/broker/broker.proto\x1a\x35github_com/TheThingsNetwork/api/handler/handler.proto\"m\n\x0e\x44\x65vicesRequest\x12L\n\x08\x64\x65v_addr\x18\x01 \x01(\x0c\x42:\xc8\xde\x1f\x00\xda\xde\x1f\x32github_com/TheThingsNetwork/ttn/core/types.DevAddr\x12\r\n\x05\x66_cnt\x18\x02 \x01(\r\"3\n\x0f\x44\x65vicesResponse\x12 \n\x07results\x18\x01 \x03(\x0b\x32\x0f.lorawan.Device\"\x0f\n\rStatusRequest\"\xe8\x01\n\x06Status\x12&\n\x06system\x18\x01 \x01(\x0b\x32\x10.api.SystemStatsB\x04\xc8\xde\x1f\x00\x12,\n\tcomponent\x18\x02 \x01(\x0b\x32\x13.api.ComponentStatsB\x04\xc8\xde\x1f\x00\x12\x1a\n\x06uplink\x18\x0b \x01(\x0b\x32\n.api.Rates\x12\x1c\n\x08\x64ownlink\x18\x0c \x01(\x0b\x32\n.api.Rates\x12\x1f\n\x0b\x61\x63tivations\x18\r \x01(\x0b\x32\n.api.Rates\x12-\n\x13\x64\x65vices_per_address\x18\x15 \x01(\x0b\x32\x10.api.Percentiles2\xab\x03\n\rNetworkServer\x12K\n\nGetDevices\x12\x1d.networkserver.DevicesRequest\x1a\x1e.networkserver.DevicesResponse\x12m\n\x11PrepareActivation\x12+.broker.DeduplicatedDeviceActivationRequest\x1a+.broker.DeduplicatedDeviceActivationRequest\x12P\n\x08\x41\x63tivate\x12!.handler.DeviceActivationResponse\x1a!.handler.DeviceActivationResponse\x12N\n\x06Uplink\x12!.broker.DeduplicatedUplinkMessage\x1a!.broker.DeduplicatedUplinkMessage\x12<\n\x08\x44ownlink\x12\x17.broker.DownlinkMessage\x1a\x17.broker.DownlinkMessage2X\n\x14NetworkServerManager\x12@\n\tGetStatus\x12\x1c.networkserver.StatusRequest\x1a\x15.networkserver.StatusB\x86\x01\n&org.thethingsnetwork.api.networkserverB\x0cMonitorProtoP\x01Z-github_com/TheThingsNetwork/api/networkserver\xaa\x02\x1cTheThingsNetwork.API.Monitorb\x06proto3')
  ,
  dependencies=[github__com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2.DESCRIPTOR,github__com_dot_TheThingsNetwork_dot_api_dot_api__pb2.DESCRIPTOR,github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.DESCRIPTOR,github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DESCRIPTOR,github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DESCRIPTOR,])




_DEVICESREQUEST = _descriptor.Descriptor(
  name='DevicesRequest',
  full_name='networkserver.DevicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dev_addr', full_name='networkserver.DevicesRequest.dev_addr', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000\332\336\0372github_com/TheThingsNetwork/ttn/core/types.DevAddr'))),
    _descriptor.FieldDescriptor(
      name='f_cnt', full_name='networkserver.DevicesRequest.f_cnt', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=454,
)


_DEVICESRESPONSE = _descriptor.Descriptor(
  name='DevicesResponse',
  full_name='networkserver.DevicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='networkserver.DevicesResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=507,
)


_STATUSREQUEST = _descriptor.Descriptor(
  name='StatusRequest',
  full_name='networkserver.StatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=524,
)


_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='networkserver.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='system', full_name='networkserver.Status.system', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000'))),
    _descriptor.FieldDescriptor(
      name='component', full_name='networkserver.Status.component', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000'))),
    _descriptor.FieldDescriptor(
      name='uplink', full_name='networkserver.Status.uplink', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='downlink', full_name='networkserver.Status.downlink', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='activations', full_name='networkserver.Status.activations', index=4,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='devices_per_address', full_name='networkserver.Status.devices_per_address', index=5,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=759,
)

_DEVICESRESPONSE.fields_by_name['results'].message_type = github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2._DEVICE
_STATUS.fields_by_name['system'].message_type = github__com_dot_TheThingsNetwork_dot_api_dot_api__pb2._SYSTEMSTATS
_STATUS.fields_by_name['component'].message_type = github__com_dot_TheThingsNetwork_dot_api_dot_api__pb2._COMPONENTSTATS
_STATUS.fields_by_name['uplink'].message_type = github__com_dot_TheThingsNetwork_dot_api_dot_api__pb2._RATES
_STATUS.fields_by_name['downlink'].message_type = github__com_dot_TheThingsNetwork_dot_api_dot_api__pb2._RATES
_STATUS.fields_by_name['activations'].message_type = github__com_dot_TheThingsNetwork_dot_api_dot_api__pb2._RATES
_STATUS.fields_by_name['devices_per_address'].message_type = github__com_dot_TheThingsNetwork_dot_api_dot_api__pb2._PERCENTILES
DESCRIPTOR.message_types_by_name['DevicesRequest'] = _DEVICESREQUEST
DESCRIPTOR.message_types_by_name['DevicesResponse'] = _DEVICESRESPONSE
DESCRIPTOR.message_types_by_name['StatusRequest'] = _STATUSREQUEST
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DevicesRequest = _reflection.GeneratedProtocolMessageType('DevicesRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICESREQUEST,
  __module__ = 'github_com.TheThingsNetwork.api.networkserver.networkserver_pb2'
  # @@protoc_insertion_point(class_scope:networkserver.DevicesRequest)
  ))
_sym_db.RegisterMessage(DevicesRequest)

DevicesResponse = _reflection.GeneratedProtocolMessageType('DevicesResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEVICESRESPONSE,
  __module__ = 'github_com.TheThingsNetwork.api.networkserver.networkserver_pb2'
  # @@protoc_insertion_point(class_scope:networkserver.DevicesResponse)
  ))
_sym_db.RegisterMessage(DevicesResponse)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATUSREQUEST,
  __module__ = 'github_com.TheThingsNetwork.api.networkserver.networkserver_pb2'
  # @@protoc_insertion_point(class_scope:networkserver.StatusRequest)
  ))
_sym_db.RegisterMessage(StatusRequest)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
  DESCRIPTOR = _STATUS,
  __module__ = 'github_com.TheThingsNetwork.api.networkserver.networkserver_pb2'
  # @@protoc_insertion_point(class_scope:networkserver.Status)
  ))
_sym_db.RegisterMessage(Status)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n&org.thethingsnetwork.api.networkserverB\014MonitorProtoP\001Z-github_com/TheThingsNetwork/api/networkserver\252\002\034TheThingsNetwork.API.Monitor'))
_DEVICESREQUEST.fields_by_name['dev_addr'].has_options = True
_DEVICESREQUEST.fields_by_name['dev_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000\332\336\0372github_com/TheThingsNetwork/ttn/core/types.DevAddr'))
_STATUS.fields_by_name['system'].has_options = True
_STATUS.fields_by_name['system']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000'))
_STATUS.fields_by_name['component'].has_options = True
_STATUS.fields_by_name['component']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000'))

_NETWORKSERVER = _descriptor.ServiceDescriptor(
  name='NetworkServer',
  full_name='networkserver.NetworkServer',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=762,
  serialized_end=1189,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetDevices',
    full_name='networkserver.NetworkServer.GetDevices',
    index=0,
    containing_service=None,
    input_type=_DEVICESREQUEST,
    output_type=_DEVICESRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PrepareActivation',
    full_name='networkserver.NetworkServer.PrepareActivation',
    index=1,
    containing_service=None,
    input_type=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2._DEDUPLICATEDDEVICEACTIVATIONREQUEST,
    output_type=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2._DEDUPLICATEDDEVICEACTIVATIONREQUEST,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='networkserver.NetworkServer.Activate',
    index=2,
    containing_service=None,
    input_type=github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2._DEVICEACTIVATIONRESPONSE,
    output_type=github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2._DEVICEACTIVATIONRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Uplink',
    full_name='networkserver.NetworkServer.Uplink',
    index=3,
    containing_service=None,
    input_type=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2._DEDUPLICATEDUPLINKMESSAGE,
    output_type=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2._DEDUPLICATEDUPLINKMESSAGE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Downlink',
    full_name='networkserver.NetworkServer.Downlink',
    index=4,
    containing_service=None,
    input_type=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2._DOWNLINKMESSAGE,
    output_type=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2._DOWNLINKMESSAGE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_NETWORKSERVER)

DESCRIPTOR.services_by_name['NetworkServer'] = _NETWORKSERVER


_NETWORKSERVERMANAGER = _descriptor.ServiceDescriptor(
  name='NetworkServerManager',
  full_name='networkserver.NetworkServerManager',
  file=DESCRIPTOR,
  index=1,
  options=None,
  serialized_start=1191,
  serialized_end=1279,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetStatus',
    full_name='networkserver.NetworkServerManager.GetStatus',
    index=0,
    containing_service=None,
    input_type=_STATUSREQUEST,
    output_type=_STATUS,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_NETWORKSERVERMANAGER)

DESCRIPTOR.services_by_name['NetworkServerManager'] = _NETWORKSERVERMANAGER

try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities


  class NetworkServerStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.GetDevices = channel.unary_unary(
          '/networkserver.NetworkServer/GetDevices',
          request_serializer=DevicesRequest.SerializeToString,
          response_deserializer=DevicesResponse.FromString,
          )
      self.PrepareActivation = channel.unary_unary(
          '/networkserver.NetworkServer/PrepareActivation',
          request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedDeviceActivationRequest.SerializeToString,
          response_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedDeviceActivationRequest.FromString,
          )
      self.Activate = channel.unary_unary(
          '/networkserver.NetworkServer/Activate',
          request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DeviceActivationResponse.SerializeToString,
          response_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DeviceActivationResponse.FromString,
          )
      self.Uplink = channel.unary_unary(
          '/networkserver.NetworkServer/Uplink',
          request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.SerializeToString,
          response_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.FromString,
          )
      self.Downlink = channel.unary_unary(
          '/networkserver.NetworkServer/Downlink',
          request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.SerializeToString,
          response_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.FromString,
          )


  class NetworkServerServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def GetDevices(self, request, context):
      """Broker requests devices with DevAddr and matching FCnt (or disabled FCnt check)
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def PrepareActivation(self, request, context):
      """Broker requests device activation "template" from Network Server
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
      """Broker confirms device activation (after response from Handler)
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Uplink(self, request, context):
      """Broker informs Network Server about Uplink
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Downlink(self, request, context):
      """Broker informs Network Server about Downlink, NetworkServer may add MAC commands and re-set MIC
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_NetworkServerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'GetDevices': grpc.unary_unary_rpc_method_handler(
            servicer.GetDevices,
            request_deserializer=DevicesRequest.FromString,
            response_serializer=DevicesResponse.SerializeToString,
        ),
        'PrepareActivation': grpc.unary_unary_rpc_method_handler(
            servicer.PrepareActivation,
            request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedDeviceActivationRequest.FromString,
            response_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedDeviceActivationRequest.SerializeToString,
        ),
        'Activate': grpc.unary_unary_rpc_method_handler(
            servicer.Activate,
            request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DeviceActivationResponse.FromString,
            response_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DeviceActivationResponse.SerializeToString,
        ),
        'Uplink': grpc.unary_unary_rpc_method_handler(
            servicer.Uplink,
            request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.FromString,
            response_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.SerializeToString,
        ),
        'Downlink': grpc.unary_unary_rpc_method_handler(
            servicer.Downlink,
            request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.FromString,
            response_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'networkserver.NetworkServer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class NetworkServerManagerStub(object):
    """The NetworkServerManager service provides configuration and monitoring
    functionality
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.GetStatus = channel.unary_unary(
          '/networkserver.NetworkServerManager/GetStatus',
          request_serializer=StatusRequest.SerializeToString,
          response_deserializer=Status.FromString,
          )


  class NetworkServerManagerServicer(object):
    """The NetworkServerManager service provides configuration and monitoring
    functionality
    """

    def GetStatus(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_NetworkServerManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'GetStatus': grpc.unary_unary_rpc_method_handler(
            servicer.GetStatus,
            request_deserializer=StatusRequest.FromString,
            response_serializer=Status.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'networkserver.NetworkServerManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetaNetworkServerServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    # missing associated documentation comment in .proto file
    pass
    def GetDevices(self, request, context):
      """Broker requests devices with DevAddr and matching FCnt (or disabled FCnt check)
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def PrepareActivation(self, request, context):
      """Broker requests device activation "template" from Network Server
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Activate(self, request, context):
      """Broker confirms device activation (after response from Handler)
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Uplink(self, request, context):
      """Broker informs Network Server about Uplink
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Downlink(self, request, context):
      """Broker informs Network Server about Downlink, NetworkServer may add MAC commands and re-set MIC
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaNetworkServerStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    # missing associated documentation comment in .proto file
    pass
    def GetDevices(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Broker requests devices with DevAddr and matching FCnt (or disabled FCnt check)
      """
      raise NotImplementedError()
    GetDevices.future = None
    def PrepareActivation(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Broker requests device activation "template" from Network Server
      """
      raise NotImplementedError()
    PrepareActivation.future = None
    def Activate(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Broker confirms device activation (after response from Handler)
      """
      raise NotImplementedError()
    Activate.future = None
    def Uplink(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Broker informs Network Server about Uplink
      """
      raise NotImplementedError()
    Uplink.future = None
    def Downlink(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Broker informs Network Server about Downlink, NetworkServer may add MAC commands and re-set MIC
      """
      raise NotImplementedError()
    Downlink.future = None


  def beta_create_NetworkServer_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('networkserver.NetworkServer', 'Activate'): github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DeviceActivationResponse.FromString,
      ('networkserver.NetworkServer', 'Downlink'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.FromString,
      ('networkserver.NetworkServer', 'GetDevices'): DevicesRequest.FromString,
      ('networkserver.NetworkServer', 'PrepareActivation'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedDeviceActivationRequest.FromString,
      ('networkserver.NetworkServer', 'Uplink'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.FromString,
    }
    response_serializers = {
      ('networkserver.NetworkServer', 'Activate'): github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DeviceActivationResponse.SerializeToString,
      ('networkserver.NetworkServer', 'Downlink'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.SerializeToString,
      ('networkserver.NetworkServer', 'GetDevices'): DevicesResponse.SerializeToString,
      ('networkserver.NetworkServer', 'PrepareActivation'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedDeviceActivationRequest.SerializeToString,
      ('networkserver.NetworkServer', 'Uplink'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.SerializeToString,
    }
    method_implementations = {
      ('networkserver.NetworkServer', 'Activate'): face_utilities.unary_unary_inline(servicer.Activate),
      ('networkserver.NetworkServer', 'Downlink'): face_utilities.unary_unary_inline(servicer.Downlink),
      ('networkserver.NetworkServer', 'GetDevices'): face_utilities.unary_unary_inline(servicer.GetDevices),
      ('networkserver.NetworkServer', 'PrepareActivation'): face_utilities.unary_unary_inline(servicer.PrepareActivation),
      ('networkserver.NetworkServer', 'Uplink'): face_utilities.unary_unary_inline(servicer.Uplink),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_NetworkServer_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('networkserver.NetworkServer', 'Activate'): github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DeviceActivationResponse.SerializeToString,
      ('networkserver.NetworkServer', 'Downlink'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.SerializeToString,
      ('networkserver.NetworkServer', 'GetDevices'): DevicesRequest.SerializeToString,
      ('networkserver.NetworkServer', 'PrepareActivation'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedDeviceActivationRequest.SerializeToString,
      ('networkserver.NetworkServer', 'Uplink'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.SerializeToString,
    }
    response_deserializers = {
      ('networkserver.NetworkServer', 'Activate'): github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.DeviceActivationResponse.FromString,
      ('networkserver.NetworkServer', 'Downlink'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.FromString,
      ('networkserver.NetworkServer', 'GetDevices'): DevicesResponse.FromString,
      ('networkserver.NetworkServer', 'PrepareActivation'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedDeviceActivationRequest.FromString,
      ('networkserver.NetworkServer', 'Uplink'): github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.FromString,
    }
    cardinalities = {
      'Activate': cardinality.Cardinality.UNARY_UNARY,
      'Downlink': cardinality.Cardinality.UNARY_UNARY,
      'GetDevices': cardinality.Cardinality.UNARY_UNARY,
      'PrepareActivation': cardinality.Cardinality.UNARY_UNARY,
      'Uplink': cardinality.Cardinality.UNARY_UNARY,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'networkserver.NetworkServer', cardinalities, options=stub_options)


  class BetaNetworkServerManagerServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """The NetworkServerManager service provides configuration and monitoring
    functionality
    """
    def GetStatus(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaNetworkServerManagerStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """The NetworkServerManager service provides configuration and monitoring
    functionality
    """
    def GetStatus(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()
    GetStatus.future = None


  def beta_create_NetworkServerManager_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('networkserver.NetworkServerManager', 'GetStatus'): StatusRequest.FromString,
    }
    response_serializers = {
      ('networkserver.NetworkServerManager', 'GetStatus'): Status.SerializeToString,
    }
    method_implementations = {
      ('networkserver.NetworkServerManager', 'GetStatus'): face_utilities.unary_unary_inline(servicer.GetStatus),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_NetworkServerManager_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('networkserver.NetworkServerManager', 'GetStatus'): StatusRequest.SerializeToString,
    }
    response_deserializers = {
      ('networkserver.NetworkServerManager', 'GetStatus'): Status.FromString,
    }
    cardinalities = {
      'GetStatus': cardinality.Cardinality.UNARY_UNARY,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'networkserver.NetworkServerManager', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from ttn.github_com.TheThingsNetwork.api.protocol.lorawan import device_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DeviceManagerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetDevice = channel.unary_unary(
        '/lorawan.DeviceManager/GetDevice',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.DeviceIdentifier.SerializeToString,
        response_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.Device.FromString,
        )
    self.SetDevice = channel.unary_unary(
        '/lorawan.DeviceManager/SetDevice',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.Device.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.DeleteDevice = channel.unary_unary(
        '/lorawan.DeviceManager/DeleteDevice',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.DeviceIdentifier.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class DeviceManagerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetDevice(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetDevice(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteDevice(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DeviceManagerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetDevice': grpc.unary_unary_rpc_method_handler(
          servicer.GetDevice,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.DeviceIdentifier.FromString,
          response_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.Device.SerializeToString,
      ),
      'SetDevice': grpc.unary_unary_rpc_method_handler(
          servicer.SetDevice,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.Device.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'DeleteDevice': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteDevice,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_protocol_dot_lorawan_dot_device__pb2.DeviceIdentifier.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'lorawan.DeviceManager', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github_com/TheThingsNetwork/api/api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='github_com/TheThingsNetwork/api/api.proto',
  package='api',
  syntax='proto3',
  serialized_pb=_b('\n)github_com/TheThingsNetwork/api/api.proto\x12\x03\x61pi\"\xd1\x01\n\x0bPercentiles\x12\x13\n\x0bpercentile1\x18\x01 \x01(\x02\x12\x13\n\x0bpercentile5\x18\x02 \x01(\x02\x12\x14\n\x0cpercentile10\x18\x03 \x01(\x02\x12\x14\n\x0cpercentile25\x18\x04 \x01(\x02\x12\x14\n\x0cpercentile50\x18\x05 \x01(\x02\x12\x14\n\x0cpercentile75\x18\x06 \x01(\x02\x12\x14\n\x0cpercentile90\x18\x07 \x01(\x02\x12\x14\n\x0cpercentile95\x18\x08 \x01(\x02\x12\x14\n\x0cpercentile99\x18\t \x01(\x02\"5\n\x05Rates\x12\r\n\x05rate1\x18\x01 \x01(\x02\x12\r\n\x05rate5\x18\x02 \x01(\x02\x12\x0e\n\x06rate15\x18\x03 \x01(\x02\"\xd3\x02\n\x0bSystemStats\x12(\n\x04load\x18\x01 \x01(\x0b\x32\x1a.api.SystemStats.Loadstats\x12&\n\x03\x63pu\x18\x02 \x01(\x0b\x32\x19.api.SystemStats.CPUStats\x12,\n\x06memory\x18\x03 \x01(\x0b\x32\x1c.api.SystemStats.MemoryStats\x1a\x39\n\tLoadstats\x12\r\n\x05load1\x18\x01 \x01(\x02\x12\r\n\x05load5\x18\x02 \x01(\x02\x12\x0e\n\x06load15\x18\x03 \x01(\x02\x1aJ\n\x08\x43PUStats\x12\x0c\n\x04user\x18\x01 \x01(\x02\x12\x0e\n\x06system\x18\x02 \x01(\x02\x12\x0c\n\x04idle\x18\x03 \x01(\x02\x12\x12\n\npercentage\x18\x04 \x01(\x02\x1a=\n\x0bMemoryStats\x12\r\n\x05total\x18\x01 \x01(\x04\x12\x11\n\tavailable\x18\x02 \x01(\x04\x12\x0c\n\x04used\x18\x03 \x01(\x04\"\xbf\x02\n\x0e\x43omponentStats\x12\x0e\n\x06uptime\x18\x01 \x01(\x04\x12)\n\x03\x63pu\x18\x02 \x01(\x0b\x32\x1c.api.ComponentStats.CPUStats\x12/\n\x06memory\x18\x03 \x01(\x0b\x32\x1f.api.ComponentStats.MemoryStats\x12\x12\n\ngoroutines\x18\x04 \x01(\x04\x12\x17\n\x0fgc_cpu_fraction\x18\x05 \x01(\x02\x1aJ\n\x08\x43PUStats\x12\x0c\n\x04user\x18\x01 \x01(\x02\x12\x0e\n\x06system\x18\x02 \x01(\x02\x12\x0c\n\x04idle\x18\x03 \x01(\x02\x12\x12\n\npercentage\x18\x04 \x01(\x02\x1aH\n\x0bMemoryStats\x12\x0e\n\x06memory\x18\x01 \x01(\x04\x12\x0c\n\x04swap\x18\x02 \x01(\x04\x12\x0c\n\x04heap\x18\n \x01(\x04\x12\r\n\x05stack\x18\x0b \x01(\x04\x42^\n\x18org.thethingsnetwork.apiB\x08\x41PIProtoP\x01Z\x1fgithub_com/TheThingsNetwork/api\xaa\x02\x14TheThingsNetwork.APIb\x06proto3')
)




_PERCENTILES = _descriptor.Descriptor(
  name='Percentiles',
  full_name='api.Percentiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentile1', full_name='api.Percentiles.percentile1', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile5', full_name='api.Percentiles.percentile5', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile10', full_name='api.Percentiles.percentile10', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile25', full_name='api.Percentiles.percentile25', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile50', full_name='api.Percentiles.percentile50', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile75', full_name='api.Percentiles.percentile75', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile90', full_name='api.Percentiles.percentile90', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile95', full_name='api.Percentiles.percentile95', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile99', full_name='api.Percentiles.percentile99', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=260,
)


_RATES = _descriptor.Descriptor(
  name='Rates',
  full_name='api.Rates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rate1', full_name='api.Rates.rate1', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate5', full_name='api.Rates.rate5', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate15', full_name='api.Rates.rate15', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=315,
)


_SYSTEMSTATS_LOADSTATS = _descriptor.Descriptor(
  name='Loadstats',
  full_name='api.SystemStats.Loadstats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load1', full_name='api.SystemStats.Loadstats.load1', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load5', full_name='api.SystemStats.Loadstats.load5', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load15', full_name='api.SystemStats.Loadstats.load15', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=518,
)

_SYSTEMSTATS_CPUSTATS = _descriptor.Descriptor(
  name='CPUStats',
  full_name='api.SystemStats.CPUStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='api.SystemStats.CPUStats.user', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='system', full_name='api.SystemStats.CPUStats.system', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='idle', full_name='api.SystemStats.CPUStats.idle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='api.SystemStats.CPUStats.percentage', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=594,
)

_SYSTEMSTATS_MEMORYSTATS = _descriptor.Descriptor(
  name='MemoryStats',
  full_name='api.SystemStats.MemoryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='api.SystemStats.MemoryStats.total', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='available', full_name='api.SystemStats.MemoryStats.available', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='used', full_name='api.SystemStats.MemoryStats.used', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=657,
)

_SYSTEMSTATS = _descriptor.Descriptor(
  name='SystemStats',
  full_name='api.SystemStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load', full_name='api.SystemStats.load', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='api.SystemStats.cpu', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memory', full_name='api.SystemStats.memory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SYSTEMSTATS_LOADSTATS, _SYSTEMSTATS_CPUSTATS, _SYSTEMSTATS_MEMORYSTATS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=657,
)


_COMPONENTSTATS_CPUSTATS = _descriptor.Descriptor(
  name='CPUStats',
  full_name='api.ComponentStats.CPUStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='api.ComponentStats.CPUStats.user', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='system', full_name='api.ComponentStats.CPUStats.system', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='idle', full_name='api.ComponentStats.CPUStats.idle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='api.ComponentStats.CPUStats.percentage', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=594,
)

_COMPONENTSTATS_MEMORYSTATS = _descriptor.Descriptor(
  name='MemoryStats',
  full_name='api.ComponentStats.MemoryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory', full_name='api.ComponentStats.MemoryStats.memory', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='swap', full_name='api.ComponentStats.MemoryStats.swap', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heap', full_name='api.ComponentStats.MemoryStats.heap', index=2,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stack', full_name='api.ComponentStats.MemoryStats.stack', index=3,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=979,
)

_COMPONENTSTATS = _descriptor.Descriptor(
  name='ComponentStats',
  full_name='api.ComponentStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uptime', full_name='api.ComponentStats.uptime', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='api.ComponentStats.cpu', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memory', full_name='api.ComponentStats.memory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='goroutines', full_name='api.ComponentStats.goroutines', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gc_cpu_fraction', full_name='api.ComponentStats.gc_cpu_fraction', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_COMPONENTSTATS_CPUSTATS, _COMPONENTSTATS_MEMORYSTATS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=979,
)

_SYSTEMSTATS_LOADSTATS.containing_type = _SYSTEMSTATS
_SYSTEMSTATS_CPUSTATS.containing_type = _SYSTEMSTATS
_SYSTEMSTATS_MEMORYSTATS.containing_type = _SYSTEMSTATS
_SYSTEMSTATS.fields_by_name['load'].message_type = _SYSTEMSTATS_LOADSTATS
_SYSTEMSTATS.fields_by_name['cpu'].message_type = _SYSTEMSTATS_CPUSTATS
_SYSTEMSTATS.fields_by_name['memory'].message_type = _SYSTEMSTATS_MEMORYSTATS
_COMPONENTSTATS_CPUSTATS.containing_type = _COMPONENTSTATS
_COMPONENTSTATS_MEMORYSTATS.containing_type = _COMPONENTSTATS
_COMPONENTSTATS.fields_by_name['cpu'].message_type = _COMPONENTSTATS_CPUSTATS
_COMPONENTSTATS.fields_by_name['memory'].message_type = _COMPONENTSTATS_MEMORYSTATS
DESCRIPTOR.message_types_by_name['Percentiles'] = _PERCENTILES
DESCRIPTOR.message_types_by_name['Rates'] = _RATES
DESCRIPTOR.message_types_by_name['SystemStats'] = _SYSTEMSTATS
DESCRIPTOR.message_types_by_name['ComponentStats'] = _COMPONENTSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Percentiles = _reflection.GeneratedProtocolMessageType('Percentiles', (_message.Message,), dict(
  DESCRIPTOR = _PERCENTILES,
  __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
  # @@protoc_insertion_point(class_scope:api.Percentiles)
  ))
_sym_db.RegisterMessage(Percentiles)

Rates = _reflection.GeneratedProtocolMessageType('Rates', (_message.Message,), dict(
  DESCRIPTOR = _RATES,
  __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
  # @@protoc_insertion_point(class_scope:api.Rates)
  ))
_sym_db.RegisterMessage(Rates)

SystemStats = _reflection.GeneratedProtocolMessageType('SystemStats', (_message.Message,), dict(

  Loadstats = _reflection.GeneratedProtocolMessageType('Loadstats', (_message.Message,), dict(
    DESCRIPTOR = _SYSTEMSTATS_LOADSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.SystemStats.Loadstats)
    ))
  ,

  CPUStats = _reflection.GeneratedProtocolMessageType('CPUStats', (_message.Message,), dict(
    DESCRIPTOR = _SYSTEMSTATS_CPUSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.SystemStats.CPUStats)
    ))
  ,

  MemoryStats = _reflection.GeneratedProtocolMessageType('MemoryStats', (_message.Message,), dict(
    DESCRIPTOR = _SYSTEMSTATS_MEMORYSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.SystemStats.MemoryStats)
    ))
  ,
  DESCRIPTOR = _SYSTEMSTATS,
  __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
  # @@protoc_insertion_point(class_scope:api.SystemStats)
  ))
_sym_db.RegisterMessage(SystemStats)
_sym_db.RegisterMessage(SystemStats.Loadstats)
_sym_db.RegisterMessage(SystemStats.CPUStats)
_sym_db.RegisterMessage(SystemStats.MemoryStats)

ComponentStats = _reflection.GeneratedProtocolMessageType('ComponentStats', (_message.Message,), dict(

  CPUStats = _reflection.GeneratedProtocolMessageType('CPUStats', (_message.Message,), dict(
    DESCRIPTOR = _COMPONENTSTATS_CPUSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.ComponentStats.CPUStats)
    ))
  ,

  MemoryStats = _reflection.GeneratedProtocolMessageType('MemoryStats', (_message.Message,), dict(
    DESCRIPTOR = _COMPONENTSTATS_MEMORYSTATS,
    __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
    # @@protoc_insertion_point(class_scope:api.ComponentStats.MemoryStats)
    ))
  ,
  DESCRIPTOR = _COMPONENTSTATS,
  __module__ = 'github_com.TheThingsNetwork.api.api_pb2'
  # @@protoc_insertion_point(class_scope:api.ComponentStats)
  ))
_sym_db.RegisterMessage(ComponentStats)
_sym_db.RegisterMessage(ComponentStats.CPUStats)
_sym_db.RegisterMessage(ComponentStats.MemoryStats)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\030org.thethingsnetwork.apiB\010APIProtoP\001Z\037github_com/TheThingsNetwork/api\252\002\024TheThingsNetwork.API'))
try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)



from .any_pb2_grpc import *
from .any_pb2 import *
from .descriptor_pb2_grpc import *
from .descriptor_pb2 import *
from .duration_pb2_grpc import *
from .duration_pb2 import *
from .empty_pb2_grpc import *
from .empty_pb2 import *
from .field_mask_pb2_grpc import *
from .field_mask_pb2 import *
from .struct_pb2_grpc import *
from .struct_pb2 import *
from .timestamp_pb2_grpc import *
from .timestamp_pb2 import *
from .wrappers_pb2_grpc import *
from .wrappers_pb2 import *



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github_com/TheThingsNetwork/api/gateway/gateway.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ttn.github_com.gogo.protobuf.gogoproto import gogo_pb2 as github__com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github_com/TheThingsNetwork/api/gateway/gateway.proto',
  package='gateway',
  syntax='proto3',
  serialized_pb=_b('\n5github_com/TheThingsNetwork/api/gateway/gateway.proto\x12\x07gateway\x1a-github_com/gogo/protobuf/gogoproto/gogo.proto\"\xf9\x01\n\x10LocationMetadata\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12\x10\n\x08latitude\x18\x02 \x01(\x02\x12\x11\n\tlongitude\x18\x03 \x01(\x02\x12\x10\n\x08\x61ltitude\x18\x04 \x01(\x05\x12\x10\n\x08\x61\x63\x63uracy\x18\x05 \x01(\x05\x12\x38\n\x06source\x18\x06 \x01(\x0e\x32(.gateway.LocationMetadata.LocationSource\"T\n\x0eLocationSource\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03GPS\x10\x01\x12\n\n\x06\x43ONFIG\x10\x02\x12\x0c\n\x08REGISTRY\x10\x03\x12\x12\n\x0eIP_GEOLOCATION\x10\x04\"\xc5\x04\n\nRxMetadata\x12!\n\ngateway_id\x18\x01 \x01(\tB\r\xe2\xde\x1f\tGatewayID\x12\x17\n\x0fgateway_trusted\x18\x02 \x01(\x08\x12\x11\n\ttimestamp\x18\x0b \x01(\r\x12\x0c\n\x04time\x18\x0c \x01(\x03\x12\x16\n\x0e\x65ncrypted_time\x18\r \x01(\x0c\x12\x10\n\x08rf_chain\x18\x15 \x01(\r\x12\x0f\n\x07\x63hannel\x18\x16 \x01(\r\x12-\n\x08\x61ntennas\x18\x1e \x03(\x0b\x32\x1b.gateway.RxMetadata.Antenna\x12\x11\n\tfrequency\x18\x1f \x01(\x04\x12\x16\n\x04rssi\x18  \x01(\x02\x42\x08\xe2\xde\x1f\x04RSSI\x12\x14\n\x03snr\x18! \x01(\x02\x42\x07\xe2\xde\x1f\x03SNR\x12+\n\x08location\x18) \x01(\x0b\x32\x19.gateway.LocationMetadata\x1a\x81\x02\n\x07\x41ntenna\x12\x0f\n\x07\x61ntenna\x18\x01 \x01(\r\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\r\x12\x16\n\x04rssi\x18\x03 \x01(\x02\x42\x08\xe2\xde\x1f\x04RSSI\x12%\n\x0c\x63hannel_rssi\x18\x05 \x01(\x02\x42\x0f\xe2\xde\x1f\x0b\x43hannelRSSI\x12:\n\x17rssi_standard_deviation\x18\x06 \x01(\x02\x42\x19\xe2\xde\x1f\x15RSSIStandardDeviation\x12\x18\n\x10\x66requency_offset\x18\x07 \x01(\x03\x12\x14\n\x03snr\x18\x04 \x01(\x02\x42\x07\xe2\xde\x1f\x03SNR\x12\x16\n\x0e\x65ncrypted_time\x18\n \x01(\x0c\x12\x11\n\tfine_time\x18\x0b \x01(\x03\"\x95\x01\n\x0fTxConfiguration\x12\x11\n\ttimestamp\x18\x0b \x01(\r\x12\x10\n\x08rf_chain\x18\x15 \x01(\r\x12\x11\n\tfrequency\x18\x16 \x01(\x04\x12\r\n\x05power\x18\x17 \x01(\x05\x12\x1e\n\x16polarization_inversion\x18\x1f \x01(\x08\x12\x1b\n\x13\x66requency_deviation\x18  \x01(\r\"\xc3\x05\n\x06Status\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x0c\n\x04time\x18\x02 \x01(\x03\x12\x17\n\x0fgateway_trusted\x18\x03 \x01(\x08\x12\x11\n\tboot_time\x18\x04 \x01(\x03\x12\x12\n\x02ip\x18\x0b \x03(\tB\x06\xe2\xde\x1f\x02IP\x12\x10\n\x08platform\x18\x0c \x01(\t\x12\x15\n\rcontact_email\x18\r \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t\x12\x16\n\x0e\x66requency_plan\x18\x0f \x01(\t\x12\x0e\n\x06\x62ridge\x18\x10 \x01(\t\x12\x0e\n\x06router\x18\x11 \x01(\t\x12\x16\n\x04\x66pga\x18\x12 \x01(\rB\x08\xe2\xde\x1f\x04\x46PGA\x12\x14\n\x03\x64sp\x18\x13 \x01(\rB\x07\xe2\xde\x1f\x03\x44SP\x12\x14\n\x03hal\x18\x14 \x01(\tB\x07\xe2\xde\x1f\x03HAL\x12+\n\x08location\x18\x15 \x01(\x0b\x32\x19.gateway.LocationMetadata\x12\x14\n\x03rtt\x18\x1f \x01(\rB\x07\xe2\xde\x1f\x03RTT\x12\r\n\x05rx_in\x18) \x01(\r\x12\r\n\x05rx_ok\x18* \x01(\r\x12\r\n\x05tx_in\x18+ \x01(\r\x12\r\n\x05tx_ok\x18, \x01(\r\x12\r\n\x05lm_ok\x18- \x01(\r\x12\r\n\x05lm_st\x18. \x01(\r\x12\r\n\x05lm_nw\x18/ \x01(\r\x12\x17\n\x05l_pps\x18\x30 \x01(\rB\x08\xe2\xde\x1f\x04LPPS\x12-\n\x02os\x18\x33 \x01(\x0b\x32\x19.gateway.Status.OSMetricsB\x06\xe2\xde\x1f\x02OS\x12\x10\n\x08messages\x18\x34 \x03(\t\x1a\x97\x01\n\tOSMetrics\x12\x0e\n\x06load_1\x18\x01 \x01(\x02\x12\x0e\n\x06load_5\x18\x02 \x01(\x02\x12\x0f\n\x07load_15\x18\x03 \x01(\x02\x12)\n\x0e\x63pu_percentage\x18\x0b \x01(\x02\x42\x11\xe2\xde\x1f\rCPUPercentage\x12\x19\n\x11memory_percentage\x18\x15 \x01(\x02\x12\x13\n\x0btemperature\x18\x1f \x01(\x02\x42z\n org.thethingsnetwork.api.gatewayB\x0cGatewayProtoP\x01Z\'github_com/TheThingsNetwork/api/gateway\xaa\x02\x1cTheThingsNetwork.API.Gatewayb\x06proto3')
  ,
  dependencies=[github__com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2.DESCRIPTOR,])



_LOCATIONMETADATA_LOCATIONSOURCE = _descriptor.EnumDescriptor(
  name='LocationSource',
  full_name='gateway.LocationMetadata.LocationSource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GPS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFIG', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REGISTRY', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IP_GEOLOCATION', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=279,
  serialized_end=363,
)
_sym_db.RegisterEnumDescriptor(_LOCATIONMETADATA_LOCATIONSOURCE)


_LOCATIONMETADATA = _descriptor.Descriptor(
  name='LocationMetadata',
  full_name='gateway.LocationMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='gateway.LocationMetadata.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='gateway.LocationMetadata.latitude', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='gateway.LocationMetadata.longitude', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='gateway.LocationMetadata.altitude', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='gateway.LocationMetadata.accuracy', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='gateway.LocationMetadata.source', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCATIONMETADATA_LOCATIONSOURCE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=363,
)


_RXMETADATA_ANTENNA = _descriptor.Descriptor(
  name='Antenna',
  full_name='gateway.RxMetadata.Antenna',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='antenna', full_name='gateway.RxMetadata.Antenna.antenna', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='gateway.RxMetadata.Antenna.channel', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rssi', full_name='gateway.RxMetadata.Antenna.rssi', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\004RSSI'))),
    _descriptor.FieldDescriptor(
      name='channel_rssi', full_name='gateway.RxMetadata.Antenna.channel_rssi', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\013ChannelRSSI'))),
    _descriptor.FieldDescriptor(
      name='rssi_standard_deviation', full_name='gateway.RxMetadata.Antenna.rssi_standard_deviation', index=4,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\025RSSIStandardDeviation'))),
    _descriptor.FieldDescriptor(
      name='frequency_offset', full_name='gateway.RxMetadata.Antenna.frequency_offset', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='snr', full_name='gateway.RxMetadata.Antenna.snr', index=6,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003SNR'))),
    _descriptor.FieldDescriptor(
      name='encrypted_time', full_name='gateway.RxMetadata.Antenna.encrypted_time', index=7,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fine_time', full_name='gateway.RxMetadata.Antenna.fine_time', index=8,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=690,
  serialized_end=947,
)

_RXMETADATA = _descriptor.Descriptor(
  name='RxMetadata',
  full_name='gateway.RxMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='gateway.RxMetadata.gateway_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\tGatewayID'))),
    _descriptor.FieldDescriptor(
      name='gateway_trusted', full_name='gateway.RxMetadata.gateway_trusted', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='gateway.RxMetadata.timestamp', index=2,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='gateway.RxMetadata.time', index=3,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encrypted_time', full_name='gateway.RxMetadata.encrypted_time', index=4,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rf_chain', full_name='gateway.RxMetadata.rf_chain', index=5,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='gateway.RxMetadata.channel', index=6,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='antennas', full_name='gateway.RxMetadata.antennas', index=7,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='gateway.RxMetadata.frequency', index=8,
      number=31, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rssi', full_name='gateway.RxMetadata.rssi', index=9,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\004RSSI'))),
    _descriptor.FieldDescriptor(
      name='snr', full_name='gateway.RxMetadata.snr', index=10,
      number=33, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003SNR'))),
    _descriptor.FieldDescriptor(
      name='location', full_name='gateway.RxMetadata.location', index=11,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_RXMETADATA_ANTENNA, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=947,
)


_TXCONFIGURATION = _descriptor.Descriptor(
  name='TxConfiguration',
  full_name='gateway.TxConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='gateway.TxConfiguration.timestamp', index=0,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rf_chain', full_name='gateway.TxConfiguration.rf_chain', index=1,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='gateway.TxConfiguration.frequency', index=2,
      number=22, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='power', full_name='gateway.TxConfiguration.power', index=3,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='polarization_inversion', full_name='gateway.TxConfiguration.polarization_inversion', index=4,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frequency_deviation', full_name='gateway.TxConfiguration.frequency_deviation', index=5,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=1099,
)


_STATUS_OSMETRICS = _descriptor.Descriptor(
  name='OSMetrics',
  full_name='gateway.Status.OSMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_1', full_name='gateway.Status.OSMetrics.load_1', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_5', full_name='gateway.Status.OSMetrics.load_5', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_15', full_name='gateway.Status.OSMetrics.load_15', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_percentage', full_name='gateway.Status.OSMetrics.cpu_percentage', index=3,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\rCPUPercentage'))),
    _descriptor.FieldDescriptor(
      name='memory_percentage', full_name='gateway.Status.OSMetrics.memory_percentage', index=4,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='gateway.Status.OSMetrics.temperature', index=5,
      number=31, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1809,
)

_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='gateway.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='gateway.Status.timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='gateway.Status.time', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gateway_trusted', full_name='gateway.Status.gateway_trusted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='boot_time', full_name='gateway.Status.boot_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='gateway.Status.ip', index=4,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\002IP'))),
    _descriptor.FieldDescriptor(
      name='platform', full_name='gateway.Status.platform', index=5,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contact_email', full_name='gateway.Status.contact_email', index=6,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='gateway.Status.description', index=7,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frequency_plan', full_name='gateway.Status.frequency_plan', index=8,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bridge', full_name='gateway.Status.bridge', index=9,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='router', full_name='gateway.Status.router', index=10,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fpga', full_name='gateway.Status.fpga', index=11,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\004FPGA'))),
    _descriptor.FieldDescriptor(
      name='dsp', full_name='gateway.Status.dsp', index=12,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003DSP'))),
    _descriptor.FieldDescriptor(
      name='hal', full_name='gateway.Status.hal', index=13,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003HAL'))),
    _descriptor.FieldDescriptor(
      name='location', full_name='gateway.Status.location', index=14,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rtt', full_name='gateway.Status.rtt', index=15,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003RTT'))),
    _descriptor.FieldDescriptor(
      name='rx_in', full_name='gateway.Status.rx_in', index=16,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rx_ok', full_name='gateway.Status.rx_ok', index=17,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tx_in', full_name='gateway.Status.tx_in', index=18,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tx_ok', full_name='gateway.Status.tx_ok', index=19,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lm_ok', full_name='gateway.Status.lm_ok', index=20,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lm_st', full_name='gateway.Status.lm_st', index=21,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lm_nw', full_name='gateway.Status.lm_nw', index=22,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='l_pps', full_name='gateway.Status.l_pps', index=23,
      number=48, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\004LPPS'))),
    _descriptor.FieldDescriptor(
      name='os', full_name='gateway.Status.os', index=24,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\002OS'))),
    _descriptor.FieldDescriptor(
      name='messages', full_name='gateway.Status.messages', index=25,
      number=52, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_STATUS_OSMETRICS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1102,
  serialized_end=1809,
)

_LOCATIONMETADATA.fields_by_name['source'].enum_type = _LOCATIONMETADATA_LOCATIONSOURCE
_LOCATIONMETADATA_LOCATIONSOURCE.containing_type = _LOCATIONMETADATA
_RXMETADATA_ANTENNA.containing_type = _RXMETADATA
_RXMETADATA.fields_by_name['antennas'].message_type = _RXMETADATA_ANTENNA
_RXMETADATA.fields_by_name['location'].message_type = _LOCATIONMETADATA
_STATUS_OSMETRICS.containing_type = _STATUS
_STATUS.fields_by_name['location'].message_type = _LOCATIONMETADATA
_STATUS.fields_by_name['os'].message_type = _STATUS_OSMETRICS
DESCRIPTOR.message_types_by_name['LocationMetadata'] = _LOCATIONMETADATA
DESCRIPTOR.message_types_by_name['RxMetadata'] = _RXMETADATA
DESCRIPTOR.message_types_by_name['TxConfiguration'] = _TXCONFIGURATION
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocationMetadata = _reflection.GeneratedProtocolMessageType('LocationMetadata', (_message.Message,), dict(
  DESCRIPTOR = _LOCATIONMETADATA,
  __module__ = 'github_com.TheThingsNetwork.api.gateway.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.LocationMetadata)
  ))
_sym_db.RegisterMessage(LocationMetadata)

RxMetadata = _reflection.GeneratedProtocolMessageType('RxMetadata', (_message.Message,), dict(

  Antenna = _reflection.GeneratedProtocolMessageType('Antenna', (_message.Message,), dict(
    DESCRIPTOR = _RXMETADATA_ANTENNA,
    __module__ = 'github_com.TheThingsNetwork.api.gateway.gateway_pb2'
    # @@protoc_insertion_point(class_scope:gateway.RxMetadata.Antenna)
    ))
  ,
  DESCRIPTOR = _RXMETADATA,
  __module__ = 'github_com.TheThingsNetwork.api.gateway.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.RxMetadata)
  ))
_sym_db.RegisterMessage(RxMetadata)
_sym_db.RegisterMessage(RxMetadata.Antenna)

TxConfiguration = _reflection.GeneratedProtocolMessageType('TxConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _TXCONFIGURATION,
  __module__ = 'github_com.TheThingsNetwork.api.gateway.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.TxConfiguration)
  ))
_sym_db.RegisterMessage(TxConfiguration)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(

  OSMetrics = _reflection.GeneratedProtocolMessageType('OSMetrics', (_message.Message,), dict(
    DESCRIPTOR = _STATUS_OSMETRICS,
    __module__ = 'github_com.TheThingsNetwork.api.gateway.gateway_pb2'
    # @@protoc_insertion_point(class_scope:gateway.Status.OSMetrics)
    ))
  ,
  DESCRIPTOR = _STATUS,
  __module__ = 'github_com.TheThingsNetwork.api.gateway.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Status)
  ))
_sym_db.RegisterMessage(Status)
_sym_db.RegisterMessage(Status.OSMetrics)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n org.thethingsnetwork.api.gatewayB\014GatewayProtoP\001Z\'github_com/TheThingsNetwork/api/gateway\252\002\034TheThingsNetwork.API.Gateway'))
_RXMETADATA_ANTENNA.fields_by_name['rssi'].has_options = True
_RXMETADATA_ANTENNA.fields_by_name['rssi']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\004RSSI'))
_RXMETADATA_ANTENNA.fields_by_name['channel_rssi'].has_options = True
_RXMETADATA_ANTENNA.fields_by_name['channel_rssi']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\013ChannelRSSI'))
_RXMETADATA_ANTENNA.fields_by_name['rssi_standard_deviation'].has_options = True
_RXMETADATA_ANTENNA.fields_by_name['rssi_standard_deviation']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\025RSSIStandardDeviation'))
_RXMETADATA_ANTENNA.fields_by_name['snr'].has_options = True
_RXMETADATA_ANTENNA.fields_by_name['snr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003SNR'))
_RXMETADATA.fields_by_name['gateway_id'].has_options = True
_RXMETADATA.fields_by_name['gateway_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\tGatewayID'))
_RXMETADATA.fields_by_name['rssi'].has_options = True
_RXMETADATA.fields_by_name['rssi']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\004RSSI'))
_RXMETADATA.fields_by_name['snr'].has_options = True
_RXMETADATA.fields_by_name['snr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003SNR'))
_STATUS_OSMETRICS.fields_by_name['cpu_percentage'].has_options = True
_STATUS_OSMETRICS.fields_by_name['cpu_percentage']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\rCPUPercentage'))
_STATUS.fields_by_name['ip'].has_options = True
_STATUS.fields_by_name['ip']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\002IP'))
_STATUS.fields_by_name['fpga'].has_options = True
_STATUS.fields_by_name['fpga']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\004FPGA'))
_STATUS.fields_by_name['dsp'].has_options = True
_STATUS.fields_by_name['dsp']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003DSP'))
_STATUS.fields_by_name['hal'].has_options = True
_STATUS.fields_by_name['hal']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003HAL'))
_STATUS.fields_by_name['rtt'].has_options = True
_STATUS.fields_by_name['rtt']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\003RTT'))
_STATUS.fields_by_name['l_pps'].has_options = True
_STATUS.fields_by_name['l_pps']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\004LPPS'))
_STATUS.fields_by_name['os'].has_options = True
_STATUS.fields_by_name['os']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\342\336\037\002OS'))
try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github_com/TheThingsNetwork/api/protocol/lorawan/device_address.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ttn.github_com.gogo.protobuf.gogoproto import gogo_pb2 as github__com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github_com/TheThingsNetwork/api/protocol/lorawan/device_address.proto',
  package='lorawan',
  syntax='proto3',
  serialized_pb=_b('\nEgithub_com/TheThingsNetwork/api/protocol/lorawan/device_address.proto\x12\x07lorawan\x1a-github_com/gogo/protobuf/gogoproto/gogo.proto\"\x11\n\x0fPrefixesRequest\"}\n\x10PrefixesResponse\x12\x39\n\x08prefixes\x18\x01 \x03(\x0b\x32\'.lorawan.PrefixesResponse.PrefixMapping\x1a.\n\rPrefixMapping\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\r\n\x05usage\x18\x02 \x03(\t\"\x1f\n\x0e\x44\x65vAddrRequest\x12\r\n\x05usage\x18\x01 \x03(\t\"_\n\x0f\x44\x65vAddrResponse\x12L\n\x08\x64\x65v_addr\x18\x01 \x01(\x0c\x42:\xc8\xde\x1f\x00\xda\xde\x1f\x32github_com/TheThingsNetwork/ttn/core/types.DevAddr2\x95\x01\n\x0e\x44\x65vAddrManager\x12\x42\n\x0bGetPrefixes\x12\x18.lorawan.PrefixesRequest\x1a\x19.lorawan.PrefixesResponse\x12?\n\nGetDevAddr\x12\x17.lorawan.DevAddrRequest\x1a\x18.lorawan.DevAddrResponseB\x9c\x01\n)org.thethingsnetwork.api.protocol.lorawanB\x14LoRaWANProtocolProtoP\x01Z0github_com/TheThingsNetwork/api/protocol/lorawan\xaa\x02$TheThingsNetwork.API.LoRaWANProtocolb\x06proto3')
  ,
  dependencies=[github__com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_PREFIXESREQUEST = _descriptor.Descriptor(
  name='PrefixesRequest',
  full_name='lorawan.PrefixesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=146,
)


_PREFIXESRESPONSE_PREFIXMAPPING = _descriptor.Descriptor(
  name='PrefixMapping',
  full_name='lorawan.PrefixesResponse.PrefixMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='lorawan.PrefixesResponse.PrefixMapping.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='usage', full_name='lorawan.PrefixesResponse.PrefixMapping.usage', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=273,
)

_PREFIXESRESPONSE = _descriptor.Descriptor(
  name='PrefixesResponse',
  full_name='lorawan.PrefixesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefixes', full_name='lorawan.PrefixesResponse.prefixes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PREFIXESRESPONSE_PREFIXMAPPING, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=273,
)


_DEVADDRREQUEST = _descriptor.Descriptor(
  name='DevAddrRequest',
  full_name='lorawan.DevAddrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='usage', full_name='lorawan.DevAddrRequest.usage', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=306,
)


_DEVADDRRESPONSE = _descriptor.Descriptor(
  name='DevAddrResponse',
  full_name='lorawan.DevAddrResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dev_addr', full_name='lorawan.DevAddrResponse.dev_addr', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000\332\336\0372github_com/TheThingsNetwork/ttn/core/types.DevAddr'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=403,
)

_PREFIXESRESPONSE_PREFIXMAPPING.containing_type = _PREFIXESRESPONSE
_PREFIXESRESPONSE.fields_by_name['prefixes'].message_type = _PREFIXESRESPONSE_PREFIXMAPPING
DESCRIPTOR.message_types_by_name['PrefixesRequest'] = _PREFIXESREQUEST
DESCRIPTOR.message_types_by_name['PrefixesResponse'] = _PREFIXESRESPONSE
DESCRIPTOR.message_types_by_name['DevAddrRequest'] = _DEVADDRREQUEST
DESCRIPTOR.message_types_by_name['DevAddrResponse'] = _DEVADDRRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PrefixesRequest = _reflection.GeneratedProtocolMessageType('PrefixesRequest', (_message.Message,), dict(
  DESCRIPTOR = _PREFIXESREQUEST,
  __module__ = 'github_com.TheThingsNetwork.api.protocol.lorawan.device_address_pb2'
  # @@protoc_insertion_point(class_scope:lorawan.PrefixesRequest)
  ))
_sym_db.RegisterMessage(PrefixesRequest)

PrefixesResponse = _reflection.GeneratedProtocolMessageType('PrefixesResponse', (_message.Message,), dict(

  PrefixMapping = _reflection.GeneratedProtocolMessageType('PrefixMapping', (_message.Message,), dict(
    DESCRIPTOR = _PREFIXESRESPONSE_PREFIXMAPPING,
    __module__ = 'github_com.TheThingsNetwork.api.protocol.lorawan.device_address_pb2'
    # @@protoc_insertion_point(class_scope:lorawan.PrefixesResponse.PrefixMapping)
    ))
  ,
  DESCRIPTOR = _PREFIXESRESPONSE,
  __module__ = 'github_com.TheThingsNetwork.api.protocol.lorawan.device_address_pb2'
  # @@protoc_insertion_point(class_scope:lorawan.PrefixesResponse)
  ))
_sym_db.RegisterMessage(PrefixesResponse)
_sym_db.RegisterMessage(PrefixesResponse.PrefixMapping)

DevAddrRequest = _reflection.GeneratedProtocolMessageType('DevAddrRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVADDRREQUEST,
  __module__ = 'github_com.TheThingsNetwork.api.protocol.lorawan.device_address_pb2'
  # @@protoc_insertion_point(class_scope:lorawan.DevAddrRequest)
  ))
_sym_db.RegisterMessage(DevAddrRequest)

DevAddrResponse = _reflection.GeneratedProtocolMessageType('DevAddrResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEVADDRRESPONSE,
  __module__ = 'github_com.TheThingsNetwork.api.protocol.lorawan.device_address_pb2'
  # @@protoc_insertion_point(class_scope:lorawan.DevAddrResponse)
  ))
_sym_db.RegisterMessage(DevAddrResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n)org.thethingsnetwork.api.protocol.lorawanB\024LoRaWANProtocolProtoP\001Z0github_com/TheThingsNetwork/api/protocol/lorawan\252\002$TheThingsNetwork.API.LoRaWANProtocol'))
_DEVADDRRESPONSE.fields_by_name['dev_addr'].has_options = True
_DEVADDRRESPONSE.fields_by_name['dev_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000\332\336\0372github_com/TheThingsNetwork/ttn/core/types.DevAddr'))

_DEVADDRMANAGER = _descriptor.ServiceDescriptor(
  name='DevAddrManager',
  full_name='lorawan.DevAddrManager',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=406,
  serialized_end=555,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetPrefixes',
    full_name='lorawan.DevAddrManager.GetPrefixes',
    index=0,
    containing_service=None,
    input_type=_PREFIXESREQUEST,
    output_type=_PREFIXESRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevAddr',
    full_name='lorawan.DevAddrManager.GetDevAddr',
    index=1,
    containing_service=None,
    input_type=_DEVADDRREQUEST,
    output_type=_DEVADDRRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEVADDRMANAGER)

DESCRIPTOR.services_by_name['DevAddrManager'] = _DEVADDRMANAGER

try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities


  class DevAddrManagerStub(object):
    """The Device Addresses in the network are issued by the NetworkServer
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.GetPrefixes = channel.unary_unary(
          '/lorawan.DevAddrManager/GetPrefixes',
          request_serializer=PrefixesRequest.SerializeToString,
          response_deserializer=PrefixesResponse.FromString,
          )
      self.GetDevAddr = channel.unary_unary(
          '/lorawan.DevAddrManager/GetDevAddr',
          request_serializer=DevAddrRequest.SerializeToString,
          response_deserializer=DevAddrResponse.FromString,
          )


  class DevAddrManagerServicer(object):
    """The Device Addresses in the network are issued by the NetworkServer
    """

    def GetPrefixes(self, request, context):
      """Get all prefixes that are in use or available
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def GetDevAddr(self, request, context):
      """Request a device address
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_DevAddrManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'GetPrefixes': grpc.unary_unary_rpc_method_handler(
            servicer.GetPrefixes,
            request_deserializer=PrefixesRequest.FromString,
            response_serializer=PrefixesResponse.SerializeToString,
        ),
        'GetDevAddr': grpc.unary_unary_rpc_method_handler(
            servicer.GetDevAddr,
            request_deserializer=DevAddrRequest.FromString,
            response_serializer=DevAddrResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'lorawan.DevAddrManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetaDevAddrManagerServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """The Device Addresses in the network are issued by the NetworkServer
    """
    def GetPrefixes(self, request, context):
      """Get all prefixes that are in use or available
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def GetDevAddr(self, request, context):
      """Request a device address
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaDevAddrManagerStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """The Device Addresses in the network are issued by the NetworkServer
    """
    def GetPrefixes(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Get all prefixes that are in use or available
      """
      raise NotImplementedError()
    GetPrefixes.future = None
    def GetDevAddr(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Request a device address
      """
      raise NotImplementedError()
    GetDevAddr.future = None


  def beta_create_DevAddrManager_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('lorawan.DevAddrManager', 'GetDevAddr'): DevAddrRequest.FromString,
      ('lorawan.DevAddrManager', 'GetPrefixes'): PrefixesRequest.FromString,
    }
    response_serializers = {
      ('lorawan.DevAddrManager', 'GetDevAddr'): DevAddrResponse.SerializeToString,
      ('lorawan.DevAddrManager', 'GetPrefixes'): PrefixesResponse.SerializeToString,
    }
    method_implementations = {
      ('lorawan.DevAddrManager', 'GetDevAddr'): face_utilities.unary_unary_inline(servicer.GetDevAddr),
      ('lorawan.DevAddrManager', 'GetPrefixes'): face_utilities.unary_unary_inline(servicer.GetPrefixes),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_DevAddrManager_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('lorawan.DevAddrManager', 'GetDevAddr'): DevAddrRequest.SerializeToString,
      ('lorawan.DevAddrManager', 'GetPrefixes'): PrefixesRequest.SerializeToString,
    }
    response_deserializers = {
      ('lorawan.DevAddrManager', 'GetDevAddr'): DevAddrResponse.FromString,
      ('lorawan.DevAddrManager', 'GetPrefixes'): PrefixesResponse.FromString,
    }
    cardinalities = {
      'GetDevAddr': cardinality.Cardinality.UNARY_UNARY,
      'GetPrefixes': cardinality.Cardinality.UNARY_UNARY,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'lorawan.DevAddrManager', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from ttn.github_com.TheThingsNetwork.api.broker import broker_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2
from ttn.github_com.TheThingsNetwork.api.gateway import gateway_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_gateway_dot_gateway__pb2
from ttn.github_com.TheThingsNetwork.api.handler import handler_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2
from ttn.github_com.TheThingsNetwork.api.networkserver import networkserver_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_networkserver_dot_networkserver__pb2
from ttn.github_com.TheThingsNetwork.api.router import router_pb2 as github__com_dot_TheThingsNetwork_dot_api_dot_router_dot_router__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class MonitorStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.RouterStatus = channel.stream_unary(
        '/monitor.Monitor/RouterStatus',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_router_dot_router__pb2.Status.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GatewayStatus = channel.stream_unary(
        '/monitor.Monitor/GatewayStatus',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_gateway_dot_gateway__pb2.Status.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GatewayUplink = channel.stream_unary(
        '/monitor.Monitor/GatewayUplink',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_router_dot_router__pb2.UplinkMessage.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GatewayDownlink = channel.stream_unary(
        '/monitor.Monitor/GatewayDownlink',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_router_dot_router__pb2.DownlinkMessage.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.BrokerStatus = channel.stream_unary(
        '/monitor.Monitor/BrokerStatus',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.Status.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.BrokerUplink = channel.stream_unary(
        '/monitor.Monitor/BrokerUplink',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.BrokerDownlink = channel.stream_unary(
        '/monitor.Monitor/BrokerDownlink',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.HandlerStatus = channel.stream_unary(
        '/monitor.Monitor/HandlerStatus',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.Status.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.HandlerUplink = channel.stream_unary(
        '/monitor.Monitor/HandlerUplink',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.HandlerDownlink = channel.stream_unary(
        '/monitor.Monitor/HandlerDownlink',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.NetworkServerStatus = channel.stream_unary(
        '/monitor.Monitor/NetworkServerStatus',
        request_serializer=github__com_dot_TheThingsNetwork_dot_api_dot_networkserver_dot_networkserver__pb2.Status.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class MonitorServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def RouterStatus(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GatewayStatus(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GatewayUplink(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GatewayDownlink(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BrokerStatus(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BrokerUplink(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BrokerDownlink(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HandlerStatus(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HandlerUplink(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def HandlerDownlink(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def NetworkServerStatus(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MonitorServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'RouterStatus': grpc.stream_unary_rpc_method_handler(
          servicer.RouterStatus,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_router_dot_router__pb2.Status.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GatewayStatus': grpc.stream_unary_rpc_method_handler(
          servicer.GatewayStatus,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_gateway_dot_gateway__pb2.Status.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GatewayUplink': grpc.stream_unary_rpc_method_handler(
          servicer.GatewayUplink,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_router_dot_router__pb2.UplinkMessage.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GatewayDownlink': grpc.stream_unary_rpc_method_handler(
          servicer.GatewayDownlink,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_router_dot_router__pb2.DownlinkMessage.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'BrokerStatus': grpc.stream_unary_rpc_method_handler(
          servicer.BrokerStatus,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.Status.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'BrokerUplink': grpc.stream_unary_rpc_method_handler(
          servicer.BrokerUplink,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'BrokerDownlink': grpc.stream_unary_rpc_method_handler(
          servicer.BrokerDownlink,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'HandlerStatus': grpc.stream_unary_rpc_method_handler(
          servicer.HandlerStatus,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_handler_dot_handler__pb2.Status.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'HandlerUplink': grpc.stream_unary_rpc_method_handler(
          servicer.HandlerUplink,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DeduplicatedUplinkMessage.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'HandlerDownlink': grpc.stream_unary_rpc_method_handler(
          servicer.HandlerDownlink,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_broker_dot_broker__pb2.DownlinkMessage.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'NetworkServerStatus': grpc.stream_unary_rpc_method_handler(
          servicer.NetworkServerStatus,
          request_deserializer=github__com_dot_TheThingsNetwork_dot_api_dot_networkserver_dot_networkserver__pb2.Status.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'monitor.Monitor', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
